==> haskell-cryptohash-md5-0.11.100.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-md5.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-md5
version: 0.11.100.1
id: cryptohash-md5-0.11.100.1-GT4rz3tsXLEGwzbmkU7JrL
key: cryptohash-md5-0.11.100.1-GT4rz3tsXLEGwzbmkU7JrL
license: BSD3
copyright: Vincent Hanquez, Herbert Valerio Riedel
maintainer: Herbert Valerio Riedel <hvr@gnu.org>
homepage: https://github.com/hvr/cryptohash-md5
synopsis: Fast, pure and practical MD5 implementation
description:
    A practical incremental and one-pass, pure API to the
    <https://en.wikipedia.org/wiki/MD5 MD5 hash algorithm>
    (including <https://en.wikipedia.org/wiki/HMAC HMAC> support)
    with performance close to the fastest implementations available in other languages.
    .
    The implementation is made in C with a haskell FFI wrapper that hides the C implementation.
    .
    NOTE: This package has been forked off @cryptohash-0.11.7@ because the @cryptohash@ package
    has been deprecated and so this package continues to satisfy the need for a lightweight package
    providing the MD5 hash algorithm without any dependencies on packages other than
    @base@ and @bytestring@.
    .
    Consequently, this package can be used as a drop-in replacement for @cryptohash@'\''s
    "Crypto.Hash.MD5" module, though with a clearly smaller footprint.
category: Data, Cryptography
exposed: True
indefinite: False
exposed-modules:
    Crypto.Hash.MD5
abi: e8a6eaf9b3e9cf259e54e3ed234d2b29
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cryptohash-md5-0.11.100.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/cryptohash-md5-0.11.100.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/cryptohash-md5-0.11.100.1
hs-libraries: HScryptohash-md5-0.11.100.1-GT4rz3tsXLEGwzbmkU7JrL
depends:
    base-4.10.0.0 bytestring-0.10.8.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
haddock-interfaces: /usr/share/doc/haskell-cryptohash-md5/html/cryptohash-md5.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-md5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-md5-0.11.100.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-md5.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-md5
version: 0.11.100.1
id: cryptohash-md5-0.11.100.1-5TVuvTUpgnc1ichC4pvrWY
key: cryptohash-md5-0.11.100.1-5TVuvTUpgnc1ichC4pvrWY
license: BSD3
copyright: Vincent Hanquez, Herbert Valerio Riedel
maintainer: Herbert Valerio Riedel <hvr@gnu.org>
homepage: https://github.com/hvr/cryptohash-md5
synopsis: Fast, pure and practical MD5 implementation
description:
    A practical incremental and one-pass, pure API to the
    <https://en.wikipedia.org/wiki/MD5 MD5 hash algorithm>
    (including <https://en.wikipedia.org/wiki/HMAC HMAC> support)
    with performance close to the fastest implementations available in other languages.
    .
    The implementation is made in C with a haskell FFI wrapper that hides the C implementation.
    .
    NOTE: This package has been forked off @cryptohash-0.11.7@ because the @cryptohash@ package
    has been deprecated and so this package continues to satisfy the need for a lightweight package
    providing the MD5 hash algorithm without any dependencies on packages other than
    @base@ and @bytestring@.
    .
    Consequently, this package can be used as a drop-in replacement for @cryptohash@'\''s
    "Crypto.Hash.MD5" module, though with a clearly smaller footprint.
category: Data, Cryptography
exposed: True
indefinite: False
exposed-modules:
    Crypto.Hash.MD5
abi: b280471d5cd8d462b00a4e5d24387326
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cryptohash-md5-0.11.100.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/cryptohash-md5-0.11.100.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/cryptohash-md5-0.11.100.1
hs-libraries: HScryptohash-md5-0.11.100.1-5TVuvTUpgnc1ichC4pvrWY
depends:
    base-4.10.1.0 bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-cryptohash-md5/html/cryptohash-md5.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-md5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
